@@ -2,6 +2,9 @@
 Helpers to access the XBlock Runtime modules.
 """
 
+from django.contrib.auth import get_user_model
+User = get_user_model()
+
 
 def get_xblock_user(xblock):
     """
@@ -10,15 +13,13 @@ def get_xblock_user(xblock):
     :param xblock: XBlock instance.
     :return: User or None.
     """
-    from django.contrib.auth import get_user_model
-    user_model = get_user_model()
-
     try:
         user_id = xblock.runtime.user_id
     except AttributeError:
         return
 
     try:
-        return user_model.objects.get(pk=user_id)
-    except user_model.DoesNotExist:
+        return User.objects.get(pk=user_id)
+    except User.DoesNotExist:
+        # TODO: This is an error and an exception should be logged
         pass
